@@ -1,7 +1,7 @@
 package Term::App::Role::Attrs;
 
-our $DATE = '2018-12-02'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2019-07-30'; # DATE
+our $VERSION = '0.030'; # VERSION
 
 use 5.010001;
 use Moo::Role;
@@ -29,7 +29,7 @@ sub _term_size {
 
     ($termw_cache, $termh_cache) = (0, 0);
     if (eval { require Term::Size; 1 }) {
-        ($termw_cache, $termh_cache) = Term::Size::chars();
+        ($termw_cache, $termh_cache) = Term::Size::chars(*STDOUT{IO});
     }
     ($termw_cache, $termh_cache);
 }
@@ -246,7 +246,7 @@ Term::App::Role::Attrs - Role for terminal-related attributes
 
 =head1 VERSION
 
-This document describes version 0.02 of Term::App::Role::Attrs (from Perl distribution Term-App-Roles), released on 2018-12-02.
+This document describes version 0.030 of Term::App::Role::Attrs (from Perl distribution Term-App-Roles), released on 2019-07-30.
 
 =head1 DESCRIPTION
 
@@ -359,7 +359,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
